@@ -85,6 +85,7 @@ alias mRadioBox XmRadioBox
 alias mRowColumn XmRowColumn
 alias mRowColumn XmRowColumn
 alias mScale XmScale
+alias mScaleSetTicks XmScaleSetTicks
 alias mScrollBar XmScrollBar
 alias mScrollBarGetValues XmScrollBarGetValues
 alias mScrollBarSetValues XmScrollBarSetValues
@@ -93,6 +94,7 @@ alias mList XmList
 alias mScrolledText XmScrolledText
 alias mText XmText
 alias mScrolledWindow XmScrolledWindow
+alias mScrollVisible XmScrollVisible
 alias mSelectionBox XmSelectionBox
 alias mSelectionBoxGetChild XmSelectionBoxGetChild
 alias mSelectionDialog XmSelectionDialog
@@ -115,6 +117,8 @@ alias mText XmText
 alias mTextClearSelection XmTextClearSelection
 alias mTextCopy XmTextCopy
 alias mTextCut XmTextCut
+alias mTextDisableRedisplay XmTextDisableRedisplay
+alias mTextEnableRedisplay XmTextEnableRedisplay
 alias mTextField XmTextField
 alias mTextFieldClearSelection XmTextFieldClearSelection
 alias mTextFieldCopy XmTextFieldCopy
@@ -131,9 +135,11 @@ alias mTextFieldRemove XmTextFieldRemove
 alias mTextFieldReplace XmTextFieldReplace
 alias mTextFieldSetAddMode XmTextFieldSetAddMode
 alias mTextFieldSetHighlight XmTextFieldSetHighlight
+alias mTextFieldSetInsertionPosition XmTextFieldSetInsertionPosition
 alias mTextFieldSetSelection XmTextFieldSetSelection
 alias mTextFieldShowPosition XmTextFieldShowPosition
 alias mTextFieldXYToPos XmTextFieldXYToPos
+alias mTextFindString XmTextFindString
 alias mTextGetBaseline XmTextGetBaseline
 alias mTextGetLastPosition XmTextGetLastPosition
 alias mTextGetSelection XmTextGetSelection
@@ -147,6 +153,7 @@ alias mTextReplace XmTextReplace
 alias mTextScroll XmTextScroll
 alias mTextSetAddMode XmTextSetAddMode
 alias mTextSetHighlight XmTextSetHighlight
+alias mTextSetInsertionPosition XmTextSetInsertionPosition
 alias mTextSetSelection XmTextSetSelection
 alias mTextShowPosition XmTextShowPosition
 alias mTextXYToPos XmTextXYToPos
@@ -164,3 +171,4 @@ alias mMessageBox XmMessageBox
 alias mActivateProtocol XmActivateProtocol
 alias mDeactivateProtocol XmDeactivateProtocol
 alias mGetString XmGetString
+alias mChangeColor XmChangeColor
